@@ -1,26 +1,23 @@
-import functools
-import time
-import inspect
 import copy
-import sys
+import functools
+import inspect
 import os
+import sys
+import time
 try:
     import SocketServer
 except ImportError:
     import socketserver as SocketServer
 
-import pymongo
+import bson
 import pymongo.collection
 import pymongo.cursor
 import pymongo.helpers
 
-from bson import SON
-
 
 __all__ = ['queries', 'inserts', 'updates', 'removes', 'install_tracker',
            'uninstall_tracker', 'reset', 'response_sizes']
 
-
 _original_methods = {
     'insert': pymongo.collection.Collection.insert,
     'update': pymongo.collection.Collection.update,
@@ -35,6 +32,10 @@ updates = []
 removes = []
 response_sizes = []
 
+if sys.version_info >= (3, 0):
+    unicode = str
+
+
 # Wrap helpers._unpack_response for getting response size
 @functools.wraps(_original_methods['_unpack_response'])
 def _unpack_response(response, *args, **kwargs):
@@ -44,28 +45,27 @@ def _unpack_response(response, *args, **kwargs):
         *args,
         **kwargs
     )
-    response_sizes.append(sys.getsizeof(response) / 1024.0)
+    response_sizes.append(sys.getsizeof(response, len(response)) / 1024.0)
     return result
 
+
 # Wrap Cursor.insert for getting queries
 @functools.wraps(_original_methods['insert'])
 def _insert(collection_self, doc_or_docs, manipulate=True,
-           safe=False, check_keys=True, **kwargs):
+            safe=None, check_keys=True, **kwargs):
     start_time = time.time()
     result = _original_methods['insert'](
         collection_self,
         doc_or_docs,
-        safe=safe,
         check_keys=check_keys,
         **kwargs
     )
     total_time = (time.time() - start_time) * 1000
 
-    __traceback_hide__ = True
+    __traceback_hide__ = True # noqa
     stack_trace, internal = _tidy_stacktrace()
     inserts.append({
         'document': doc_or_docs,
-        'safe': safe,
         'time': total_time,
         'stack_trace': stack_trace,
         'size': response_sizes[-1] if response_sizes else 0,
@@ -73,30 +73,29 @@ def _insert(collection_self, doc_or_docs, manipulate=True,
     })
     return result
 
+
 # Wrap Cursor.update for getting queries
 @functools.wraps(_original_methods['update'])
 def _update(collection_self, spec, document, upsert=False,
-           maniuplate=False, safe=False, multi=False, **kwargs):
+            maniuplate=False, safe=None, multi=False, **kwargs):
     start_time = time.time()
     result = _original_methods['update'](
         collection_self,
         spec,
         document,
         upsert=upsert,
-        safe=safe,
         multi=multi,
         **kwargs
     )
     total_time = (time.time() - start_time) * 1000
 
-    __traceback_hide__ = True
+    __traceback_hide__ = True # noqa
     stack_trace, internal = _tidy_stacktrace()
     updates.append({
         'document': document,
         'upsert': upsert,
         'multi': multi,
         'spec': spec,
-        'safe': safe,
         'time': total_time,
         'stack_trace': stack_trace,
         'size': response_sizes[-1] if response_sizes else 0,
@@ -104,23 +103,22 @@ def _update(collection_self, spec, document, upsert=False,
     })
     return result
 
+
 # Wrap Cursor.remove for getting queries
 @functools.wraps(_original_methods['remove'])
-def _remove(collection_self, spec_or_id, safe=False, **kwargs):
+def _remove(collection_self, spec_or_id, safe=None, **kwargs):
     start_time = time.time()
     result = _original_methods['remove'](
         collection_self,
         spec_or_id,
-        safe=safe,
         **kwargs
     )
     total_time = (time.time() - start_time) * 1000
 
-    __traceback_hide__ = True
+    __traceback_hide__ = True # noqa
     stack_trace, internal = _tidy_stacktrace()
     removes.append({
         'spec_or_id': spec_or_id,
-        'safe': safe,
         'time': total_time,
         '   ': stack_trace,
         'size': response_sizes[-1] if response_sizes else 0,
@@ -128,12 +126,13 @@ def _remove(collection_self, spec_or_id, safe=False, **kwargs):
     })
     return result
 
+
 # Wrap Cursor._refresh for getting queries
 @functools.wraps(_original_methods['refresh'])
 def _cursor_refresh(cursor_self):
     # Look up __ private instance variables
     def privar(name):
-        return getattr(cursor_self, '_Cursor__{0}'.format(name))
+        return getattr(cursor_self, '_Cursor__{0}'.format(name), None)
 
     if privar('id') is not None:
         # getMore not query - move on
@@ -148,7 +147,7 @@ def _cursor_refresh(cursor_self):
     total_time = (time.time() - start_time) * 1000
 
     query_son = privar('query_spec')()
-    if not isinstance(query_son, SON):
+    if not isinstance(query_son, bson.SON):
 
         if "$query" not in query_son:
             query_son = {"$query": query_son}
@@ -173,7 +172,7 @@ def _cursor_refresh(cursor_self):
         if maxScan:
             query_son["$maxScan"] = maxScan
 
-    __traceback_hide__ = True
+    __traceback_hide__ = True # noqa
     stack_trace, internal = _tidy_stacktrace()
     query_data = {
         'time': total_time,
@@ -209,6 +208,7 @@ def _cursor_refresh(cursor_self):
 
     return result
 
+
 def install_tracker():
     if pymongo.collection.Collection.insert != _insert:
         pymongo.collection.Collection.insert = _insert
@@ -221,6 +221,7 @@ def install_tracker():
     if pymongo.helpers._unpack_response != _unpack_response:
         pymongo.helpers._unpack_response = _unpack_response
 
+
 def uninstall_tracker():
     if pymongo.collection.Collection.insert == _insert:
         pymongo.collection.Collection.insert = _original_methods['insert']
@@ -233,6 +234,7 @@ def uninstall_tracker():
     if pymongo.helpers._unpack_response == _unpack_response:
         pymongo.helpers._unpack_response = _original_methods['_unpack_response']
 
+
 def reset():
     global queries, inserts, updates, removes, response_sizes
     queries = []
@@ -241,6 +243,7 @@ def reset():
     removes = []
     response_sizes = []
 
+
 def _get_ordering(son):
     """Helper function to extract formatted ordering from dict.
     """
@@ -250,6 +253,7 @@ def _get_ordering(son):
     if '$orderby' in son:
         return ', '.join(fmt(f, d) for f, d in son['$orderby'].items())
 
+
 def _tidy_stacktrace():
     """
     Tidy the stack_trace
@@ -261,12 +265,7 @@ def _tidy_stacktrace():
 
     # Check html templates
     fnames = []
-    _range = None
-    if sys.version_info >= (3, 0):
-        _range = range(100)
-    else:
-        _range = xrange(100)
-    for i in _range:
+    for i in range(100):
         try:
             fname = sys._getframe(i).f_code.co_filename
             if '.html' in fname:
@@ -305,6 +304,9 @@ def _tidy_stacktrace():
             if sys.version_info >= (3, 0):
                 text = ''.join(text).strip()
             else:
-                text = unicode(''.join(text).strip(), errors="ignore")
+                try:
+                    text = unicode(''.join(text).strip())
+                except:
+                    pass
         trace.append((path, line_no, func_name, text, hidden))
     return trace, internal
