@@ -1,13 +1,11 @@
 from flask import current_app
-
 from flask_debugtoolbar.panels import DebugPanel
-from jinja2 import PackageLoader, ChoiceLoader
+from jinja2 import ChoiceLoader, PackageLoader
+
 from flask_mongoengine import operation_tracker
 
-_ = lambda x: x
 
-
-package_loader = PackageLoader('flask.ext.mongoengine', 'templates')
+package_loader = PackageLoader('flask_mongoengine', 'templates')
 
 
 def _maybe_patch_jinja_loader(jinja_env):
@@ -42,8 +40,8 @@ class MongoDebugPanel(DebugPanel):
     def nav_subtitle(self):
         attrs = ['queries', 'inserts', 'updates', 'removes']
         ops = sum(sum((1 for o in getattr(operation_tracker, a)
-                         if not o['internal']))
-                         for a in attrs)
+                      if not o['internal']))
+                  for a in attrs)
         total_time = sum(sum(o['time'] for o in getattr(operation_tracker, a))
                          for a in attrs)
         return '{0} operations in {1:.2f}ms'.format(ops, total_time)
