@@ -1,21 +1,23 @@
 """
 Useful form fields for use with the mongoengine.
 """
-from gettext import gettext as _
 import json
 import sys
 
-from wtforms import widgets
-from wtforms.fields import SelectFieldBase, TextAreaField, StringField
-from wtforms.validators import ValidationError
-
+from gettext import gettext as _
 from mongoengine.queryset import DoesNotExist
-from mongoengine.python_support import txt_type, bin_type
+import six
+from wtforms import widgets
+from wtforms.fields import SelectFieldBase, StringField, TextAreaField
+from wtforms.validators import ValidationError
 
 __all__ = (
     'ModelSelectField', 'QuerySetSelectField',
 )
 
+if sys.version_info >= (3, 0):
+    unicode = str
+
 
 class QuerySetSelectField(SelectFieldBase):
     """
@@ -35,8 +37,10 @@ class QuerySetSelectField(SelectFieldBase):
     """
     widget = widgets.Select()
 
-    def __init__(self, label=u'', validators=None, queryset=None, label_attr='',
-                 allow_blank=False, blank_text=u'---', **kwargs):
+    def __init__(self, label=u'', validators=None, queryset=None,
+                 label_attr='', allow_blank=False, blank_text=u'---',
+                 **kwargs):
+
         super(QuerySetSelectField, self).__init__(label, validators, **kwargs)
         self.label_attr = label_attr
         self.allow_blank = allow_blank
@@ -69,8 +73,7 @@ class QuerySetSelectField(SelectFieldBase):
                     return
 
                 try:
-                    # clone() because of https://github.com/MongoEngine/mongoengine/issues/56
-                    obj = self.queryset.clone().get(id=valuelist[0])
+                    obj = self.queryset.get(pk=valuelist[0])
                     self.data = obj
                 except DoesNotExist:
                     self.data = None
@@ -88,11 +91,16 @@ class QuerySetSelectMultipleField(QuerySetSelectField):
 
     widget = widgets.Select(multiple=True)
 
-    def  __init__(self, label=u'', validators=None, queryset=None, label_attr='',
-                  allow_blank=False, blank_text=u'---', **kwargs):
-        super(QuerySetSelectMultipleField, self).__init__(label, validators, queryset, label_attr, allow_blank, blank_text, **kwargs)
+    def __init__(self, label=u'', validators=None, queryset=None,
+                 label_attr='', allow_blank=False, blank_text=u'---',
+                 **kwargs):
+
+        super(QuerySetSelectMultipleField, self).__init__(
+            label, validators, queryset, label_attr, allow_blank, blank_text,
+            **kwargs)
 
     def process_formdata(self, valuelist):
+
         if valuelist:
             if valuelist[0] == '__None':
                 self.data = None
@@ -102,10 +110,14 @@ class QuerySetSelectMultipleField(QuerySetSelectField):
                     return
 
                 self.queryset.rewind()
-                self.data = [obj for obj in self.queryset if str(obj.id) in valuelist]
+                self.data = list(self.queryset(pk__in=valuelist))
                 if not len(self.data):
                     self.data = None
 
+        # If no value passed, empty the list
+        else:
+            self.data = None
+
     def _is_selected(self, item):
         return item in self.data if self.data else False
 
@@ -155,21 +167,20 @@ class NoneStringField(StringField):
     """
     Custom StringField that counts "" as None
     """
-
     def process_formdata(self, valuelist):
         if valuelist:
             self.data = valuelist[0]
         if self.data == "":
             self.data = None
 
+
 class BinaryField(TextAreaField):
     """
-    Custom TextAreaField that converts its value with bin_type.
+    Custom TextAreaField that converts its value with binary_type.
     """
-
     def process_formdata(self, valuelist):
         if valuelist:
-            if sys.version_info >= (3, 0):
-                self.data = bin_type( valuelist[0], 'utf-8' )
+            if six.PY3:
+                self.data = six.binary_type(valuelist[0], 'utf-8')
             else:
-                self.data = bin_type( valuelist[0] )
+                self.data = six.binary_type(valuelist[0])
